*******************
Doc de ``datasets``
*******************


Voici l'autodocumentation d'un package/module

Datasets
========

.. automodule:: datasets.datasets
   :members:
   :undoc-members:
   :show-inheritance: